# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
# pylint: disable=wrong-import-position

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from ._patch import *  # pylint: disable=unused-wildcard-import


from ._models import (  # type: ignore
    AccessModeSettings,
    AccessModeSettingsExclusion,
    AccessRule,
    AccessRuleProperties,
    AccessRulePropertiesSubscription,
    ActionDetail,
    ActionGroup,
    ActionGroupPatch,
    ActionGroupPatchBody,
    ActionGroupResource,
    ActionGroupResourceProperties,
    ActionList,
    Actions,
    ActivityLogAlertErrorResponse,
    ActivityLogAlertResource,
    AdxDestination,
    AgentSetting,
    AgentSettingsSpec,
    AlertRuleAllOfCondition,
    AlertRuleAnyOfOrLeafCondition,
    AlertRuleLeafCondition,
    AlertRulePatchObject,
    AlertRulePatchProperties,
    AlertRuleProperties,
    ApplicationInsights,
    ArmRoleReceiver,
    AutomationRunbookReceiver,
    AutoscaleErrorResponse,
    AutoscaleErrorResponseError,
    AutoscaleNotification,
    AutoscaleProfile,
    AutoscaleSetting,
    AutoscaleSettingResource,
    AutoscaleSettingResourcePatch,
    AzureAppPushReceiver,
    AzureFunctionReceiver,
    AzureMonitorMetricsDestination,
    AzureMonitorPrivateLinkScope,
    AzureMonitorPrivateLinkScopeProperties,
    BaselineMetadata,
    ColumnDefinition,
    Condition,
    ConditionFailingPeriods,
    ConfigurationAccessEndpointSpec,
    Context,
    DataCollectionEndpoint,
    DataCollectionEndpointConfigurationAccess,
    DataCollectionEndpointFailoverConfiguration,
    DataCollectionEndpointLogsIngestion,
    DataCollectionEndpointMetadata,
    DataCollectionEndpointMetricsIngestion,
    DataCollectionEndpointNetworkAcls,
    DataCollectionEndpointResource,
    DataCollectionEndpointResourceIdentity,
    DataCollectionEndpointResourceProperties,
    DataCollectionEndpointResourceSku,
    DataCollectionRule,
    DataCollectionRuleAgentSettings,
    DataCollectionRuleAssociation,
    DataCollectionRuleAssociationMetadata,
    DataCollectionRuleAssociationProxyOnlyResource,
    DataCollectionRuleAssociationProxyOnlyResourceProperties,
    DataCollectionRuleDataSources,
    DataCollectionRuleDestinations,
    DataCollectionRuleDirectDataSources,
    DataCollectionRuleEndpoints,
    DataCollectionRuleIngestionQuotas,
    DataCollectionRuleMetadata,
    DataCollectionRuleReferences,
    DataCollectionRuleResource,
    DataCollectionRuleResourceIdentity,
    DataCollectionRuleResourceProperties,
    DataCollectionRuleResourceSku,
    DataFlow,
    DataImportSources,
    DataImportSourcesEventHub,
    DataSourcesSpec,
    DataSourcesSpecDataImports,
    DestinationsSpec,
    DestinationsSpecAzureMonitorMetrics,
    Dimension,
    DirectDataSourcesSpec,
    DynamicMetricCriteria,
    DynamicPromQLCriteria,
    DynamicThresholdFailingPeriods,
    EmailNotification,
    EmailReceiver,
    EnableRequest,
    EndpointsSpec,
    EnrichmentData,
    ErrorAdditionalInfo,
    ErrorContract,
    ErrorDetail,
    ErrorDetailAdditionalInfoItem,
    ErrorDetailAutoGenerated,
    ErrorResponse,
    ErrorResponseAutoGenerated,
    ErrorResponseCommon,
    ErrorResponseCommonV2,
    ErrorResponseError,
    ErrorResponseErrorAdditionalInfoItem,
    EtwProviderDataSource,
    EventData,
    EventHubDataSource,
    EventHubDestination,
    EventHubDirectDestination,
    EventHubReceiver,
    ExtensionDataSource,
    ExtensionResource,
    FailoverConfigurationSpec,
    HttpRequestInfo,
    Identity,
    IisLogsDataSource,
    Incident,
    IncidentReceiver,
    IncidentServiceConnection,
    IngestionQuotas,
    IngestionQuotasLogs,
    ItsmReceiver,
    LocalizableString,
    LocationSpec,
    LogAnalyticsDestination,
    LogFileSettings,
    LogFileSettingsText,
    LogFileTextSettings,
    LogFilesDataSource,
    LogFilesDataSourceSettings,
    LogProfileProperties,
    LogProfileResource,
    LogProfileResourcePatch,
    LogSettings,
    LogicAppReceiver,
    LogsIngestionEndpointSpec,
    LogsQuotaSpec,
    ManagedServiceIdentity,
    Metadata,
    MetadataValue,
    Metric,
    MetricAlertAction,
    MetricAlertCriteria,
    MetricAlertErrorResponse,
    MetricAlertMultipleResourceMultipleMetricCriteria,
    MetricAlertProperties,
    MetricAlertPropertiesPatch,
    MetricAlertResource,
    MetricAlertResourcePatch,
    MetricAlertSingleResourceMultipleMetricCriteria,
    MetricAlertStatus,
    MetricAlertStatusCollection,
    MetricAlertStatusProperties,
    MetricAvailability,
    MetricBaselinesErrorResponse,
    MetricBaselinesProperties,
    MetricCriteria,
    MetricDefinition,
    MetricDimension,
    MetricNamespace,
    MetricNamespaceName,
    MetricSettings,
    MetricSingleDimension,
    MetricTrigger,
    MetricValue,
    MetricsIngestionEndpointSpec,
    MicrosoftFabricDestination,
    MonitoringAccountDestination,
    MultiMetricCriteria,
    MultiPromQLCriteria,
    NetworkRuleSet,
    NetworkSecurityPerimeter,
    NetworkSecurityPerimeterConfiguration,
    NetworkSecurityPerimeterConfigurationProperties,
    NetworkSecurityProfile,
    NotificationRequestBody,
    OperationStatus,
    OtelDataSourceResourceAttributeRouting,
    OtelLogsDataSource,
    OtelLogsDataSourceResourceAttributeRouting,
    OtelLogsDirectDataSource,
    OtelMetricsDataSource,
    OtelMetricsDataSourceResourceAttributeRouting,
    OtelMetricsDirectDataSource,
    OtelTracesDataSource,
    OtelTracesDataSourceResourceAttributeRouting,
    OtelTracesDirectDataSource,
    PerfCounterDataSource,
    PerformanceCountersOTelDataSource,
    PlatformTelemetryDataSource,
    PredictiveAutoscalePolicy,
    PredictiveResponse,
    PredictiveValue,
    PrivateEndpoint,
    PrivateEndpointConnection,
    PrivateEndpointConnectionProperties,
    PrivateLinkResource,
    PrivateLinkResourceProperties,
    PrivateLinkScopedResource,
    PrivateLinkServiceConnectionState,
    PromQLCriteria,
    PrometheusForwarderDataSource,
    ProvisioningIssue,
    ProvisioningIssueProperties,
    ProxyResource,
    QueryFailingPeriods,
    Recurrence,
    RecurrentSchedule,
    ReferencesSpec,
    ReferencesSpecEnrichmentData,
    ResolveConfiguration,
    Resource,
    ResourceAssociation,
    ResourceForUpdate,
    ResourceForUpdateIdentity,
    Response,
    RetentionPolicy,
    RuleResolveConfiguration,
    ScaleAction,
    ScaleCapacity,
    ScaleRule,
    ScaleRuleMetricDimension,
    ScheduledQueryRuleCriteria,
    ScheduledQueryRuleProperties,
    ScheduledQueryRuleResource,
    ScheduledQueryRuleResourcePatch,
    ScopedResource,
    ScopedResourceProperties,
    SenderAuthorization,
    ServiceDiagnosticSettings,
    ServiceDiagnosticSettingsResource,
    ServiceDiagnosticSettingsResourcePatch,
    SingleBaseline,
    SingleMetricBaseline,
    Sku,
    SmsReceiver,
    StaticPromQLCriteria,
    StorageBlob,
    StorageBlobDestination,
    StorageTableDestination,
    StreamDeclaration,
    SubscriptionScopeMetricDefinition,
    SubscriptionScopeMetricsRequestBodyParameters,
    SyslogDataSource,
    SystemData,
    TagsResource,
    TestNotificationDetailsResponse,
    TimeSeriesBaseline,
    TimeSeriesElement,
    TimeWindow,
    TrackedResource,
    UserAssignedIdentity,
    UserIdentityProperties,
    VoiceReceiver,
    WebhookNotification,
    WebhookReceiver,
    WebtestLocationAvailabilityCriteria,
    WindowsEventLogDataSource,
    WindowsFirewallLogsDataSource,
)

from ._enums import (  # type: ignore
    AccessMode,
    AccessRuleDirection,
    AggregationType,
    AggregationTypeEnum,
    AlertSeverity,
    BaselineSensitivity,
    ComparisonOperationType,
    ConditionOperator,
    CreatedByType,
    CriterionType,
    DimensionOperator,
    DynamicThresholdOperator,
    DynamicThresholdSensitivity,
    EventLevel,
    IdentityType,
    IncidentManagementService,
    IssueType,
    Kind,
    KnownAgentSettingName,
    KnownColumnDefinitionType,
    KnownDataCollectionEndpointProvisioningState,
    KnownDataCollectionEndpointResourceKind,
    KnownDataCollectionRuleAssociationProvisioningState,
    KnownDataCollectionRuleProvisioningState,
    KnownDataCollectionRuleResourceKind,
    KnownDataFlowStreams,
    KnownEtwProviderDataSourceLogLevel,
    KnownEtwProviderType,
    KnownExtensionDataSourceStreams,
    KnownLocationSpecProvisioningStatus,
    KnownLogFileTextSettingsRecordStartTimestampFormat,
    KnownLogFilesDataSourceFormat,
    KnownOtelLogsDataSourceStreams,
    KnownOtelLogsDirectDataSourceStreams,
    KnownOtelTracesDataSourceStreams,
    KnownOtelTracesDirectDataSourceStreams,
    KnownPerfCounterDataSourceStreams,
    KnownPerformanceCountersOTelDataSourceStreams,
    KnownPrometheusForwarderDataSourceStreams,
    KnownPublicNetworkAccessOptions,
    KnownStorageBlobLookupType,
    KnownSyslogDataSourceFacilityNames,
    KnownSyslogDataSourceLogLevels,
    KnownSyslogDataSourceStreams,
    KnownWindowsEventLogDataSourceStreams,
    KnownWindowsFirewallLogsDataSourceProfileFilter,
    ManagedServiceIdentityType,
    MetricAggregationType,
    MetricClass,
    MetricResultType,
    MetricStatisticType,
    MetricUnit,
    NamespaceClassification,
    NetworkSecurityPerimeterConfigurationProvisioningState,
    Odatatype,
    OperationType,
    Operator,
    PredictiveAutoscalePolicyScaleMode,
    PrivateEndpointConnectionProvisioningState,
    PrivateEndpointServiceConnectionStatus,
    PrivateLinkScopeProvisioningState,
    ReceiverStatus,
    RecurrenceFrequency,
    ResourceAssociationAccessMode,
    ResultType,
    ScaleDirection,
    ScaleRuleMetricDimensionOperationType,
    ScaleType,
    ScopedResourceKind,
    ScopedResourceProvisioningState,
    Severity,
    SkuTier,
    TimeAggregation,
    TimeAggregationType,
)
from ._patch import __all__ as _patch_all
from ._patch import *
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "AccessModeSettings",
    "AccessModeSettingsExclusion",
    "AccessRule",
    "AccessRuleProperties",
    "AccessRulePropertiesSubscription",
    "ActionDetail",
    "ActionGroup",
    "ActionGroupPatch",
    "ActionGroupPatchBody",
    "ActionGroupResource",
    "ActionGroupResourceProperties",
    "ActionList",
    "Actions",
    "ActivityLogAlertErrorResponse",
    "ActivityLogAlertResource",
    "AdxDestination",
    "AgentSetting",
    "AgentSettingsSpec",
    "AlertRuleAllOfCondition",
    "AlertRuleAnyOfOrLeafCondition",
    "AlertRuleLeafCondition",
    "AlertRulePatchObject",
    "AlertRulePatchProperties",
    "AlertRuleProperties",
    "ApplicationInsights",
    "ArmRoleReceiver",
    "AutomationRunbookReceiver",
    "AutoscaleErrorResponse",
    "AutoscaleErrorResponseError",
    "AutoscaleNotification",
    "AutoscaleProfile",
    "AutoscaleSetting",
    "AutoscaleSettingResource",
    "AutoscaleSettingResourcePatch",
    "AzureAppPushReceiver",
    "AzureFunctionReceiver",
    "AzureMonitorMetricsDestination",
    "AzureMonitorPrivateLinkScope",
    "AzureMonitorPrivateLinkScopeProperties",
    "BaselineMetadata",
    "ColumnDefinition",
    "Condition",
    "ConditionFailingPeriods",
    "ConfigurationAccessEndpointSpec",
    "Context",
    "DataCollectionEndpoint",
    "DataCollectionEndpointConfigurationAccess",
    "DataCollectionEndpointFailoverConfiguration",
    "DataCollectionEndpointLogsIngestion",
    "DataCollectionEndpointMetadata",
    "DataCollectionEndpointMetricsIngestion",
    "DataCollectionEndpointNetworkAcls",
    "DataCollectionEndpointResource",
    "DataCollectionEndpointResourceIdentity",
    "DataCollectionEndpointResourceProperties",
    "DataCollectionEndpointResourceSku",
    "DataCollectionRule",
    "DataCollectionRuleAgentSettings",
    "DataCollectionRuleAssociation",
    "DataCollectionRuleAssociationMetadata",
    "DataCollectionRuleAssociationProxyOnlyResource",
    "DataCollectionRuleAssociationProxyOnlyResourceProperties",
    "DataCollectionRuleDataSources",
    "DataCollectionRuleDestinations",
    "DataCollectionRuleDirectDataSources",
    "DataCollectionRuleEndpoints",
    "DataCollectionRuleIngestionQuotas",
    "DataCollectionRuleMetadata",
    "DataCollectionRuleReferences",
    "DataCollectionRuleResource",
    "DataCollectionRuleResourceIdentity",
    "DataCollectionRuleResourceProperties",
    "DataCollectionRuleResourceSku",
    "DataFlow",
    "DataImportSources",
    "DataImportSourcesEventHub",
    "DataSourcesSpec",
    "DataSourcesSpecDataImports",
    "DestinationsSpec",
    "DestinationsSpecAzureMonitorMetrics",
    "Dimension",
    "DirectDataSourcesSpec",
    "DynamicMetricCriteria",
    "DynamicPromQLCriteria",
    "DynamicThresholdFailingPeriods",
    "EmailNotification",
    "EmailReceiver",
    "EnableRequest",
    "EndpointsSpec",
    "EnrichmentData",
    "ErrorAdditionalInfo",
    "ErrorContract",
    "ErrorDetail",
    "ErrorDetailAdditionalInfoItem",
    "ErrorDetailAutoGenerated",
    "ErrorResponse",
    "ErrorResponseAutoGenerated",
    "ErrorResponseCommon",
    "ErrorResponseCommonV2",
    "ErrorResponseError",
    "ErrorResponseErrorAdditionalInfoItem",
    "EtwProviderDataSource",
    "EventData",
    "EventHubDataSource",
    "EventHubDestination",
    "EventHubDirectDestination",
    "EventHubReceiver",
    "ExtensionDataSource",
    "ExtensionResource",
    "FailoverConfigurationSpec",
    "HttpRequestInfo",
    "Identity",
    "IisLogsDataSource",
    "Incident",
    "IncidentReceiver",
    "IncidentServiceConnection",
    "IngestionQuotas",
    "IngestionQuotasLogs",
    "ItsmReceiver",
    "LocalizableString",
    "LocationSpec",
    "LogAnalyticsDestination",
    "LogFileSettings",
    "LogFileSettingsText",
    "LogFileTextSettings",
    "LogFilesDataSource",
    "LogFilesDataSourceSettings",
    "LogProfileProperties",
    "LogProfileResource",
    "LogProfileResourcePatch",
    "LogSettings",
    "LogicAppReceiver",
    "LogsIngestionEndpointSpec",
    "LogsQuotaSpec",
    "ManagedServiceIdentity",
    "Metadata",
    "MetadataValue",
    "Metric",
    "MetricAlertAction",
    "MetricAlertCriteria",
    "MetricAlertErrorResponse",
    "MetricAlertMultipleResourceMultipleMetricCriteria",
    "MetricAlertProperties",
    "MetricAlertPropertiesPatch",
    "MetricAlertResource",
    "MetricAlertResourcePatch",
    "MetricAlertSingleResourceMultipleMetricCriteria",
    "MetricAlertStatus",
    "MetricAlertStatusCollection",
    "MetricAlertStatusProperties",
    "MetricAvailability",
    "MetricBaselinesErrorResponse",
    "MetricBaselinesProperties",
    "MetricCriteria",
    "MetricDefinition",
    "MetricDimension",
    "MetricNamespace",
    "MetricNamespaceName",
    "MetricSettings",
    "MetricSingleDimension",
    "MetricTrigger",
    "MetricValue",
    "MetricsIngestionEndpointSpec",
    "MicrosoftFabricDestination",
    "MonitoringAccountDestination",
    "MultiMetricCriteria",
    "MultiPromQLCriteria",
    "NetworkRuleSet",
    "NetworkSecurityPerimeter",
    "NetworkSecurityPerimeterConfiguration",
    "NetworkSecurityPerimeterConfigurationProperties",
    "NetworkSecurityProfile",
    "NotificationRequestBody",
    "OperationStatus",
    "OtelDataSourceResourceAttributeRouting",
    "OtelLogsDataSource",
    "OtelLogsDataSourceResourceAttributeRouting",
    "OtelLogsDirectDataSource",
    "OtelMetricsDataSource",
    "OtelMetricsDataSourceResourceAttributeRouting",
    "OtelMetricsDirectDataSource",
    "OtelTracesDataSource",
    "OtelTracesDataSourceResourceAttributeRouting",
    "OtelTracesDirectDataSource",
    "PerfCounterDataSource",
    "PerformanceCountersOTelDataSource",
    "PlatformTelemetryDataSource",
    "PredictiveAutoscalePolicy",
    "PredictiveResponse",
    "PredictiveValue",
    "PrivateEndpoint",
    "PrivateEndpointConnection",
    "PrivateEndpointConnectionProperties",
    "PrivateLinkResource",
    "PrivateLinkResourceProperties",
    "PrivateLinkScopedResource",
    "PrivateLinkServiceConnectionState",
    "PromQLCriteria",
    "PrometheusForwarderDataSource",
    "ProvisioningIssue",
    "ProvisioningIssueProperties",
    "ProxyResource",
    "QueryFailingPeriods",
    "Recurrence",
    "RecurrentSchedule",
    "ReferencesSpec",
    "ReferencesSpecEnrichmentData",
    "ResolveConfiguration",
    "Resource",
    "ResourceAssociation",
    "ResourceForUpdate",
    "ResourceForUpdateIdentity",
    "Response",
    "RetentionPolicy",
    "RuleResolveConfiguration",
    "ScaleAction",
    "ScaleCapacity",
    "ScaleRule",
    "ScaleRuleMetricDimension",
    "ScheduledQueryRuleCriteria",
    "ScheduledQueryRuleProperties",
    "ScheduledQueryRuleResource",
    "ScheduledQueryRuleResourcePatch",
    "ScopedResource",
    "ScopedResourceProperties",
    "SenderAuthorization",
    "ServiceDiagnosticSettings",
    "ServiceDiagnosticSettingsResource",
    "ServiceDiagnosticSettingsResourcePatch",
    "SingleBaseline",
    "SingleMetricBaseline",
    "Sku",
    "SmsReceiver",
    "StaticPromQLCriteria",
    "StorageBlob",
    "StorageBlobDestination",
    "StorageTableDestination",
    "StreamDeclaration",
    "SubscriptionScopeMetricDefinition",
    "SubscriptionScopeMetricsRequestBodyParameters",
    "SyslogDataSource",
    "SystemData",
    "TagsResource",
    "TestNotificationDetailsResponse",
    "TimeSeriesBaseline",
    "TimeSeriesElement",
    "TimeWindow",
    "TrackedResource",
    "UserAssignedIdentity",
    "UserIdentityProperties",
    "VoiceReceiver",
    "WebhookNotification",
    "WebhookReceiver",
    "WebtestLocationAvailabilityCriteria",
    "WindowsEventLogDataSource",
    "WindowsFirewallLogsDataSource",
    "AccessMode",
    "AccessRuleDirection",
    "AggregationType",
    "AggregationTypeEnum",
    "AlertSeverity",
    "BaselineSensitivity",
    "ComparisonOperationType",
    "ConditionOperator",
    "CreatedByType",
    "CriterionType",
    "DimensionOperator",
    "DynamicThresholdOperator",
    "DynamicThresholdSensitivity",
    "EventLevel",
    "IdentityType",
    "IncidentManagementService",
    "IssueType",
    "Kind",
    "KnownAgentSettingName",
    "KnownColumnDefinitionType",
    "KnownDataCollectionEndpointProvisioningState",
    "KnownDataCollectionEndpointResourceKind",
    "KnownDataCollectionRuleAssociationProvisioningState",
    "KnownDataCollectionRuleProvisioningState",
    "KnownDataCollectionRuleResourceKind",
    "KnownDataFlowStreams",
    "KnownEtwProviderDataSourceLogLevel",
    "KnownEtwProviderType",
    "KnownExtensionDataSourceStreams",
    "KnownLocationSpecProvisioningStatus",
    "KnownLogFileTextSettingsRecordStartTimestampFormat",
    "KnownLogFilesDataSourceFormat",
    "KnownOtelLogsDataSourceStreams",
    "KnownOtelLogsDirectDataSourceStreams",
    "KnownOtelTracesDataSourceStreams",
    "KnownOtelTracesDirectDataSourceStreams",
    "KnownPerfCounterDataSourceStreams",
    "KnownPerformanceCountersOTelDataSourceStreams",
    "KnownPrometheusForwarderDataSourceStreams",
    "KnownPublicNetworkAccessOptions",
    "KnownStorageBlobLookupType",
    "KnownSyslogDataSourceFacilityNames",
    "KnownSyslogDataSourceLogLevels",
    "KnownSyslogDataSourceStreams",
    "KnownWindowsEventLogDataSourceStreams",
    "KnownWindowsFirewallLogsDataSourceProfileFilter",
    "ManagedServiceIdentityType",
    "MetricAggregationType",
    "MetricClass",
    "MetricResultType",
    "MetricStatisticType",
    "MetricUnit",
    "NamespaceClassification",
    "NetworkSecurityPerimeterConfigurationProvisioningState",
    "Odatatype",
    "OperationType",
    "Operator",
    "PredictiveAutoscalePolicyScaleMode",
    "PrivateEndpointConnectionProvisioningState",
    "PrivateEndpointServiceConnectionStatus",
    "PrivateLinkScopeProvisioningState",
    "ReceiverStatus",
    "RecurrenceFrequency",
    "ResourceAssociationAccessMode",
    "ResultType",
    "ScaleDirection",
    "ScaleRuleMetricDimensionOperationType",
    "ScaleType",
    "ScopedResourceKind",
    "ScopedResourceProvisioningState",
    "Severity",
    "SkuTier",
    "TimeAggregation",
    "TimeAggregationType",
]
__all__.extend([p for p in _patch_all if p not in __all__])  # pyright: ignore
_patch_sdk()
