# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
# pylint: disable=wrong-import-position

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from ._patch import *  # pylint: disable=unused-wildcard-import

from ._operations import PrivateLinkResourcesOperations  # type: ignore
from ._operations import PrivateEndpointConnectionsOperations  # type: ignore
from ._operations import DataCollectionEndpointsOperations  # type: ignore
from ._operations import ScheduledQueryRuleOperations  # type: ignore
from ._operations import DataCollectionRuleAssociationsOperations  # type: ignore
from ._operations import DataCollectionRulesOperations  # type: ignore
from ._operations import PrivateLinkScopesOperations  # type: ignore
from ._operations import PrivateLinkScopedResourcesOperations  # type: ignore
from ._operations import PrivateLinkScopeOperationStatusOperations  # type: ignore
from ._operations import AutoscaleSettingsOperations  # type: ignore
from ._operations import PredictiveMetricOperations  # type: ignore
from ._operations import ActivityLogsOperations  # type: ignore
from ._operations import EventCategoriesOperations  # type: ignore
from ._operations import TenantActivityLogsOperations  # type: ignore
from ._operations import MetricDefinitionsOperations  # type: ignore
from ._operations import MetricNamespacesOperations  # type: ignore
from ._operations import MetricsOperations  # type: ignore
from ._operations import ServiceDiagnosticSettingsOperations  # type: ignore
from ._operations import AlertRuleIncidentsOperations  # type: ignore
from ._operations import LogProfilesOperations  # type: ignore
from ._operations import ActivityLogAlertsOperations  # type: ignore
from ._operations import MetricAlertsOperations  # type: ignore
from ._operations import MetricAlertsStatusOperations  # type: ignore
from ._operations import ScheduledQueryRulesOperations  # type: ignore
from ._operations import BaselinesOperations  # type: ignore
from ._operations import ActionGroupsOperations  # type: ignore

from ._patch import __all__ as _patch_all
from ._patch import *
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "PrivateLinkResourcesOperations",
    "PrivateEndpointConnectionsOperations",
    "DataCollectionEndpointsOperations",
    "ScheduledQueryRuleOperations",
    "DataCollectionRuleAssociationsOperations",
    "DataCollectionRulesOperations",
    "PrivateLinkScopesOperations",
    "PrivateLinkScopedResourcesOperations",
    "PrivateLinkScopeOperationStatusOperations",
    "AutoscaleSettingsOperations",
    "PredictiveMetricOperations",
    "ActivityLogsOperations",
    "EventCategoriesOperations",
    "TenantActivityLogsOperations",
    "MetricDefinitionsOperations",
    "MetricNamespacesOperations",
    "MetricsOperations",
    "ServiceDiagnosticSettingsOperations",
    "AlertRuleIncidentsOperations",
    "LogProfilesOperations",
    "ActivityLogAlertsOperations",
    "MetricAlertsOperations",
    "MetricAlertsStatusOperations",
    "ScheduledQueryRulesOperations",
    "BaselinesOperations",
    "ActionGroupsOperations",
]
__all__.extend([p for p in _patch_all if p not in __all__])  # pyright: ignore
_patch_sdk()
